==> owlapi-parsers-3.4.1-sources.jar: org/coode/owlapi/owlxmlparser/AbstractOWLAssertionAxiomElementHandler.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.coode.owlapi.owlxmlparser;

import org.semanticweb.owlapi.model.OWLIndividual;
import org.semanticweb.owlapi.model.OWLObject;
import org.semanticweb.owlapi.model.OWLPropertyExpression;


/**
 * Author: Matthew Horridge<br>
 * The University Of Manchester<br>
 * Bio-Health Informatics Group<br>
 * Date: 14-Dec-2006<br><br>
 */
@SuppressWarnings("javadoc")
public abstract class AbstractOWLAssertionAxiomElementHandler<P extends OWLPropertyExpression<?,?>, O extends OWLObject> extends AbstractOWLAxiomElementHandler {


    private OWLIndividual subject;

    private P property;

    private O object;


    public AbstractOWLAssertionAxiomElementHandler(OWLXMLParserHandler handler) {
        super(handler);
    }


    public OWLIndividual getSubject() {
        return subject;
    }


    public P getProperty() {
        return property;
    }


    public O getObject() {
        return object;
    }


    public void setSubject(OWLIndividual subject) {
        this.subject = subject;
    }


    public void setProperty(P property) {
        this.property = property;
    }


    public void setObject(O object) {
        this.object = object;
    }
}

==> owlapi-parsers-3.5.0-sources.jar: org/coode/owlapi/owlxmlparser/AbstractOWLAssertionAxiomElementHandler.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.coode.owlapi.owlxmlparser;

import org.semanticweb.owlapi.model.OWLIndividual;
import org.semanticweb.owlapi.model.OWLObject;
import org.semanticweb.owlapi.model.OWLPropertyExpression;

/**
 * @author Matthew Horridge, The University Of Manchester, Bio-Health Informatics
 *         Group, Date: 14-Dec-2006
 * @param <P>
 *        property type
 * @param <O>
 *        object type
 */
public abstract class AbstractOWLAssertionAxiomElementHandler<P extends OWLPropertyExpression<?, ?>, O extends OWLObject>
        extends AbstractOWLAxiomElementHandler {

    private OWLIndividual subject;
    private P property;
    private O object;

    /**
     * @param handler
     *        owlxml handler
     */
    public AbstractOWLAssertionAxiomElementHandler(OWLXMLParserHandler handler) {
        super(handler);
    }

    /** @return subject */
    public OWLIndividual getSubject() {
        return subject;
    }

    /** @return property */
    public P getProperty() {
        return property;
    }

    /** @return object */
    public O getObject() {
        return object;
    }

    /**
     * @param subject
     *        subject
     */
    public void setSubject(OWLIndividual subject) {
        this.subject = subject;
    }

    /**
     * @param property
     *        property
     */
    public void setProperty(P property) {
        this.property = property;
    }

    /**
     * @param object
     *        object
     */
    public void setObject(O object) {
        this.object = object;
    }
}
